import { Ref } from "vue";
import { LocationQueryValue, RouteLocationNormalizedLoaded, Router } from "vue-router";
export declare type TabEntry = {
    id: string;
    scrollDestId?: string;
};
export declare type AppendTabFunction = (entry: TabEntry) => void;
export declare type RemoveTabFunction = (entry: TabEntry) => void;
export declare type SelectTabEventHandler = (event: {
    id: string;
    scrollDestId?: string;
}) => void;
export declare type TabHandler = {
    currentTabIndex: Ref<number>;
    currentTabId: Ref<string | undefined>;
    appendTab: AppendTabFunction;
    removeTab: RemoveTabFunction;
    selectTab: SelectTabEventHandler;
};
export declare type ScrollToTabOption = {
    offset: number;
};
export declare const TAB_HANDLER: unique symbol;
export declare const useTabHandler: () => TabHandler | undefined;
/**
 * `UiTabs` 를 router 에 연결해 사용할 때 필요한
 * `selectedTabId` 변수와 `changeRouterTab` 함수를 리턴한다.
 *
 * ```html
 * <UiTabs v-model="selectedTabId" @update:modelValue="changeRouterTab">
 * ```
 *
 * ```ts
 * setup() {
 *   return {
 *     ...useRouterTab(router, route, 'tab')
 *   }
 * }
 * ```
 * @param router Router 객체. `useRouter()` 로 얻을 수 있다.
 * @param route Route 객체. `useRoute()` 로 얻을 수 있다.
 * @param defaultTabId router query 에 탭이 없을 때 디폴트 값으로 사용되는 tab id.
 * @param paramName router query 에 추가될 파라미터 명
 */
export declare const useRouterTab: (router: Router, route: RouteLocationNormalizedLoaded, defaultTabId: string, paramName?: string) => {
    selectedTabId: Ref<string | LocationQueryValue[] | null>;
    changeRouterTab: (tabId: string, tabs: Ref<TabEntry[]>) => void;
};
